## What does this PR do?

<!-- Brief description of the change -->

## Checklist

- [ ] `make check` passes (lint, format, typecheck, tests)
- [ ] Tests added or updated for new/changed code
- [ ] 100% test coverage maintained
